@@ -3,6 +3,6 @@ Line simulation made with pygame for testing
 a robot's pathfinding abilities.
 """
 
-from .beacons import Magnet
-from .sensors import Line, Ultrasonic, Hall
+from .beacons import Magnet, Infrared
+from .sensors import Line, Ultrasonic, Hall, IR
 from .linesim import LineSimulation, Robot
